import glob
import re
import os
import shutil

# Funktion, die die spezifischen Ersetzungen in einem gegebenen Text durchführt
def replace_content(text):
    replacements = {
        r'style="fill-rule: evenodd; fill: #e6e6e6; "': r'style="fill-rule: evenodd; fill:param(fill) #ffffff; fill-opacity:1"', #Grundfarbe
        r'style="fill-rule: evenodd; fill: #999999; "': r'style="fill-rule: evenodd; fill: #000000; fill-opacity: 0"', #Schatten 2
        r'style="fill-rule: evenodd; fill: #ffffff; "': r'style="fill-rule: evenodd; fill: #ffffff; fill-opacity: 1"', #Licht
        r'style="stroke-width: 0.2160; stroke: #000000; stroke-dasharray: none; stroke-linecap: round; stroke-linejoin: miter; fill: none; "': r'style="stroke-width:param(outline-width) 0.25; stroke:param(outline) #000000; stroke-dasharray: none; stroke-linecap: round; stroke-linejoin: miter; fill: none"', #Schraffen
        r'style="fill-rule: evenodd; fill: #000000; "': r'style="fill-rule: evenodd; fill: #000000; fill-opacity:param(fill-opacity) 1"', # Schatten 1
        r'style="stroke-width: 0.3399; stroke: #000000; stroke-dasharray: none; stroke-linecap: round; stroke-linejoin: round; fill: none; "': r'style="stroke-width:param(outline-width) 0.35; stroke:param(outline) #000000; stroke-dasharray: none; stroke-linecap: round; stroke-linejoin: round; fill: none"', #Außenlinie
        r'<path d="  ': r'<path d="',
        r'; "': r';"',
        r'" />': r'"/>',
    }
    
    for old, new in replacements.items():
        text = re.sub(old, new, text)
        
    return text

# Funktion zum Finden des nächsten "alt##"-Verzeichnisnamens und dessen Erstellung
def create_backup_directory(base_path):
    existing_dirs = [d for d in os.listdir(base_path) if os.path.isdir(os.path.join(base_path, d)) and d.startswith('alt')]
    highest_num = 0
    for d in existing_dirs:
        try:
            num = int(d[3:])
            highest_num = max(highest_num, num)
        except ValueError:
            continue  # Falls das Verzeichnis nicht der erwarteten Benennung folgt, ignorieren
    
    # Nächsten Verzeichnisnamen festlegen und Verzeichnis erstellen
    next_dir_name = f'alt{highest_num + 1:02d}'
    next_dir_path = os.path.join(base_path, next_dir_name)
    os.makedirs(next_dir_path, exist_ok=True)
    return next_dir_path

# Funktion zum Kopieren der SVG-Dateien ins Sicherungsverzeichnis und Durchführen der Ersetzungen
def backup_and_update_svgs(directory, backup_directory):
    for i in range(1, 64):  # Für MH01.svg bis MH63.svg
        file_name = f'MH{i:02d}.svg'
        file_path = os.path.join(directory, file_name)
        
        if os.path.exists(file_path):
            # Datei ins Sicherungsverzeichnis kopieren
            shutil.copy(file_path, backup_directory)
            
            # Datei öffnen, lesen und Ersetzungen durchführen
            with open(file_path, 'r', encoding='utf-8') as file:
                content = file.read()
            updated_content = replace_content(content)
            
            # Geänderten Inhalt zurückschreiben
            with open(file_path, 'w', encoding='utf-8') as file:
                file.write(updated_content)

# Hauptskript
def main():
    current_directory = os.getcwd()
    backup_directory = create_backup_directory(current_directory)
    backup_and_update_svgs(current_directory, backup_directory)

# Den Aufruf der Hauptfunktion aktivieren, um das Skript auszuführen
main()

# Dieses Skript enthält alle notwendigen Funktionen und Schritte, um die angeforderten Ersetzungen durchzuführen und gleichzeitig eine Sicherungskopie der Originaldateien anzulegen.
